import { world, ItemStack, system, } from '@minecraft/server';


system.beforeEvents.startup.subscribe(eventData => {
  eventData.blockComponentRegistry.registerCustomComponent('component:elemental_alter_particle', {
    onTick({ player, block, dimension }) {
      const { x, y, z } = block;
      if (block.north(2).east(2).typeId === ("cata:alter_pedestal")
        && block.north(2).west(2).typeId === ("cata:alter_pedestal")
        && block.south(2).west(2).typeId === ("cata:alter_pedestal")
        && block.south(2).east(2).typeId === ("cata:alter_pedestal")) {
        dimension.runCommand(`particle cata:elemental_alter_emitter ${x} ${y} ${z} `)
      }
    }
  })
})

system.beforeEvents.startup.subscribe(eventData => {
  eventData.blockComponentRegistry.registerCustomComponent('component:elemental_alter_empty', {
    onPlayerInteract({ block, dimension, player }) {
      const { x, y, z } = block;
      const equipment = player.getComponent('equippable'); {
        const selectedItem = equipment.getEquipment('Mainhand');
        if (selectedItem?.typeId == 'minecraft:experience_bottle') {
          block.setPermutation(block.permutation.withState('cata:powered', true));
          player.playSound('beacon.activate', { pitch: 2, location: player.location, volume: 0.4 })
          if (player.getGameMode() !== "creative") {
            player.runCommand(`clear @s minecraft:experience_bottle 0 1`)
          }
        }
      }
    }
  })
})

system.beforeEvents.startup.subscribe(eventData => {
  eventData.blockComponentRegistry.registerCustomComponent('component:elemental_alter_powered', {
    onPlayerInteract({ block, player, dimension }) {
      const { x, y, z } = block;
      const playerEquippableComp = player.getComponent("equippable");
      const equipment = player.getComponent('equippable'); {

        const random = Math.random()
        const selectedItem = equipment.getEquipment('Mainhand');

        //floret_tablet
        if (selectedItem?.typeId == 'cata:floret_tablet' ||
          selectedItem?.typeId == 'cata:floret_tablet_conjure1' ||
          selectedItem?.typeId == 'cata:floret_tablet_conjure2' ||
          selectedItem?.typeId == 'cata:floret_tablet_projectile1'
          && block.north(2).east(2).hasTag('alter_pedestal_floret')
          && block.north(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).east(2).hasTag('alter_pedestal_floret')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          if (random < 0.50) {
            playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:floret_tablet_projectile1', 1));
          } else if (random < 0.50) {
            playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:floret_tablet_conjure2', 1));
          } else if (random < 1) {
            playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:floret_tablet_conjure1', 1));
          }
        }
        //master_verdant_key
        if (selectedItem?.typeId == 'cata:verdant_key'
          && block.north(2).east(2).hasTag('alter_pedestal_floret')
          && block.north(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).east(2).hasTag('alter_pedestal_floret')
          && block.north(2).typeId === ('cata:floret_block')
          && block.east(2).typeId === ('cata:floret_block')
          && block.south(2).typeId === ('cata:floret_block')
          && block.west(2).typeId === ('cata:floret_block')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x} ${y} ${z - 2} air destroy`)
          dimension.runCommand(`setblock ${x} ${y} ${z + 2} air destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z} air destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z} air destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:master_verdant_key', 1));
        }
        //Floret Hatchet
        if (selectedItem?.typeId == 'cata:verdant_sword'
          && block.north(2).east(2).hasTag('alter_pedestal_floret')
          && block.north(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).east(2).hasTag('alter_pedestal_floret')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:floret_hatchet', 1));
        }
        //Floret Wand
        if (selectedItem?.typeId == 'cata:stellar_wand'
          && block.north(2).east(2).hasTag('alter_pedestal_floret')
          && block.north(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).west(2).hasTag('alter_pedestal_floret')
          && block.south(2).east(2).hasTag('alter_pedestal_floret')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:floret_wand', 1));
        }
        //Morningstar
        if (selectedItem?.typeId == 'minecraft:netherite_sword'
          && block.north(2).east(2).hasTag('alter_pedestal_solar')
          && block.north(2).west(2).hasTag('alter_pedestal_solar')
          && block.south(2).west(2).hasTag('alter_pedestal_solar')
          && block.south(2).east(2).hasTag('alter_pedestal_solar')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
        }
        //Astral Jel
        if (selectedItem?.typeId == 'minecraft:slime_ball'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          player.runCommand(`give @s cata:astral_jel 1`)
          if (player.getGameMode() !== "creative") {
            player.runCommand(`clear @s minecraft:slime_ball 0 1`)
          }
        }
        //Stellar Charm
        if (selectedItem?.typeId == 'cata:charm'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:stellar_charm', 1));
        }
        //Astral Blade
        if (selectedItem?.typeId == 'minecraft:iron_sword'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:astral_blade', 1));
        }
        //Stellar Armor
        if (selectedItem?.typeId == 'minecraft:iron_helmet'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:stellar_helmet', 1));
        }
        if (selectedItem?.typeId == 'minecraft:iron_chestplate'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:stellar_chestplate', 1));
        }
        if (selectedItem?.typeId == 'minecraft:iron_leggings'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:stellar_leggings', 1));
        }
        if (selectedItem?.typeId == 'minecraft:iron_boots'
          && block.north(2).east(2).hasTag('alter_pedestal_astral')
          && block.north(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).west(2).hasTag('alter_pedestal_astral')
          && block.south(2).east(2).hasTag('alter_pedestal_astral')) {
          player.playSound('random.anvil_land', { pitch: 1.3, location: player.location, volume: 0.6 })
          dimension.runCommand(`setblock ${x - 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x + 2} ${y} ${z - 2} cata:alter_pedestal destroy`)
          dimension.runCommand(`setblock ${x - 2} ${y} ${z + 2} cata:alter_pedestal destroy`)
          block.setPermutation(block.permutation.withState('cata:powered', false));
          playerEquippableComp.setEquipment("Mainhand", new ItemStack('cata:stellar_boots', 1));
        }
      }
    }
  })
})

