import { world, system, EquipmentSlot } from "@minecraft/server";
import { TicksPerSecond } from "@minecraft/server";

//Charm
world.afterEvents.itemUse.subscribe((data) => {
    const player = data.source
    const selectedItem = player.getComponent('equippable').getEquipment('Mainhand')
    if (selectedItem?.typeId === 'cata:stellar_charm' && !player.hasTag('stellar_charm') && !player.getItemCooldown('charm')) {
        player.startItemCooldown('charm', 60)
        player.runCommand('tag @s add stellar_charm')
        player.runCommand('particle cata:stellar_charm_activate ~ ~ ~ ')
        player.playSound('beacon.activate', { pitch: 3, location: player.location, volume: 0.4 })
    } else if (selectedItem?.typeId === 'cata:stellar_charm' && player.hasTag('stellar_charm') && !player.getItemCooldown('charm')) {
        player.startItemCooldown('charm', 60)
        player.runCommand('tag @s remove stellar_charm')
        player.runCommand('particle cata:stellar_charm_deactivate ~ ~ ~ ')
        player.playSound('beacon.deactivate', { pitch: 3, location: player.location, volume: 0.4 })
    }
})

system.runInterval(
    () => {
        world.getAllPlayers().filter(
            (player) => {
                if (player.hasTag('stellar_charm')) {
                    player.runCommand('particle cata:astral_crit ~ ~ ~ ')
                }
            }
        )
    }, 60)

world.afterEvents.entityHurt.subscribe(({ damageSource: { damagingEntity: source }, hurtEntity: player }) => {
    if (!source) return;
    const { x, z } = source.getViewDirection();
    if (source.hasTag('stellar_charm')) {
        const random = Math.random()
        if (random < 0.15) {
            source.addEffect("regeneration", TicksPerSecond * 10, { amplifier: 0, showParticles: false });
            source.runCommand('particle cata:stellar_charm_heart ~ ~ ~ ')
        } else if (random < 1) {
        }
    }
});

world.afterEvents.entityHurt.subscribe(event => {
    const equipmentInventory = event.hurtEntity.getComponent("equippable");
    if (event.hurtEntity?.typeId == 'minecraft:player' && event.hurtEntity.hasTag('stellar_charm')) {
        event.damageSource.damagingEntity.runCommand("particle cata:astral_weapon_emitter ~ ~ ~")
        event.damageSource.damagingEntity.applyDamage(3)
    }
})


//veradant_blade
world.afterEvents.itemStartUse.subscribe((data) => {
    const player = data.source
    const selectedItem = player.getComponent('equippable').getEquipment('Mainhand')
    if (selectedItem?.typeId === 'cata:verdant_blade') {
        player.runCommand('tag @s add verdant_second_attack')
    }
})
world.afterEvents.itemReleaseUse.subscribe((data) => {
    const player = data.source
    const selectedItem = player.getComponent('equippable').getEquipment('Mainhand')
    if (selectedItem?.typeId === 'cata:verdant_blade') {
        player.runCommand('tag @s remove verdant_second_attack')
    }
})
system.runInterval(
    () => {
        world.getAllPlayers().filter(
            (player) => {
                const selectedItem = player.getComponent('equippable').getEquipment('Mainhand')
                if (player.hasTag('verdant_second_attack') && selectedItem?.typeId === 'cata:verdant_blade') {
                    player.runCommand('damage @e[r=5,family=!player, type=!item] 10 entity_attack entity @s')
                    player.runCommand('particle cata:verdant_sweep ^^0.1^2.5')
                    player.runCommand('particle cata:verdant_sweep ^2^0.1^2.5')
                    player.runCommand('particle cata:verdant_sweep ^-2^0.1^2.5')
                    player.runCommand('particle cata:verdant_sweep ^-3^0.1^1.5')
                    player.runCommand('particle cata:verdant_sweep ^3^0.1^1.5')
                }
            }
        )
    }, 12)
system.runInterval(
    () => {
        world.getAllPlayers().filter(
            (player) => {
                const selectedItem = player.getComponent('equippable').getEquipment('Mainhand')
                if (player.hasTag('verdant_second_attack') && selectedItem?.typeId != 'cata:verdant_blade') {
                    player.runCommand('tag @s remove verdant_second_attack')
                }
            }
        )
    },
)
